@@ -3,9 +3,9 @@ package ScriptX::Debug::DumpStash;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-10-01'; # DATE
 our $DIST = 'ScriptX'; # DIST
-our $VERSION = '0.000003'; # VERSION
+our $VERSION = '0.000004'; # VERSION
 
-use parent 'ScriptX::Base';
+use parent 'ScriptX_Base';
 
 sub meta {
     return {
@@ -41,7 +41,7 @@ ScriptX::Debug::DumpStash - Dump stash
 
 =head1 VERSION
 
-This document describes version 0.000003 of ScriptX::Debug::DumpStash (from Perl distribution ScriptX), released on 2020-10-01.
+This document describes version 0.000004 of ScriptX::Debug::DumpStash (from Perl distribution ScriptX), released on 2020-10-01.
 
 =head1 DESCRIPTION
 
