@@ -3,7 +3,7 @@ package ScriptX::DisablePlugin;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-10-01'; # DATE
 our $DIST = 'ScriptX'; # DIST
-our $VERSION = '0.000003'; # VERSION
+our $VERSION = '0.000004'; # VERSION
 
 # IFUNBUILT
 # use strict;
@@ -11,7 +11,7 @@ our $VERSION = '0.000003'; # VERSION
 # END IFUNBUILT
 use Log::ger;
 
-use parent 'ScriptX::Base';
+use parent 'ScriptX_Base';
 
 sub meta {
     return {
@@ -82,7 +82,7 @@ ScriptX::DisablePlugin - Prevent the loading (activation) of other plugins
 
 =head1 VERSION
 
-This document describes version 0.000003 of ScriptX::DisablePlugin (from Perl distribution ScriptX), released on 2020-10-01.
+This document describes version 0.000004 of ScriptX::DisablePlugin (from Perl distribution ScriptX), released on 2020-10-01.
 
 =head1 SYNOPSIS
 
