@@ -1,6 +1,6 @@
 package ScriptX::Getopt::Long;
 
-use parent 'ScriptX::Base';
+use parent 'ScriptX_Base';
 
 sub meta {
     return {
@@ -46,7 +46,7 @@ ScriptX::Getopt::Long - Parse command-line options using Getop::Long
 
 =head1 VERSION
 
-This document describes version 0.000003 of ScriptX::Getopt::Long (from Perl distribution ScriptX), released on 2020-10-01.
+This document describes version 0.000004 of ScriptX::Getopt::Long (from Perl distribution ScriptX), released on 2020-10-01.
 
 =head1 SYNOPSIS
 
